@@ -1,9 +1,9 @@
 package DDD;
 
 our $DATE = '2016-01-12'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
-use Data::Dump qw(dd);
+use Data::Dump;
 
 sub import {
     my $class = shift;
@@ -25,7 +25,7 @@ DDD - Dump data for debugging
 
 =head1 VERSION
 
-This document describes version 0.01 of DDD (from Perl distribution DDD), released on 2016-01-12.
+This document describes version 0.02 of DDD (from Perl distribution DDD), released on 2016-01-12.
 
 =head1 SYNOPSIS
 
@@ -40,7 +40,8 @@ L<DDD> is basically just a shortcut for:
 except that it's shorter and you don't have to import anything.
 
 It aids in print-based debugging session. You don't have to add a separate
-C<use> statement.
+C<use> statement. The drawback is that it's executed in compile-time phase and
+thus are useless in a lot of cases.
 
 =head1 SEE ALSO
 
